body
{
  background: #05111B;
  color: #A0A0A0;
  font-size: 0.8em;
  margin: 0;
}

A
{
  color: #A0A0A0; text-decoration: underline;
}

A:link
{
  color: #A0A0A0; text-decoration: underline;
}

A:visited
{
  color: #A0A0A0; text-decoration: underline;
}

A:active
{
  color: #A0A0A0;
}

A:hover
{
  color: #FFFFA0;
}

form
{
  display: inline;
}

input, textarea, option, select
{
  background: #25313B;
  color: #A0A0A0;
  border: 1px solid #45686B;
}

textarea
{
  font-family: monospace;
  margin-top: 5px;
}

iframe
{
  margin-top: 5px;
}

#header
{
  margin: 0;
  min-height: 50px;
  padding: 10px;
  moz-border-radius: 5px 5px 5px 5px;
}

#footer
{
  margin: 0;
}

#page
{
  position: relative;
  left: 210px;
  padding: 10px 10px 10px 10px;
  width: 750px;
}

#sidebar
{
  position: fixed;
  margin: 10px 10px 10px 10px;
  width: 200px;	
  top: 0;
}

#sidebar h1
{
  font-size: 1em;
  margin: 0;
  text-align: center;
  background-color: #25313B;
}

#sidebar ul
{
  padding: 0;
  margin: 0;
}

#sidebar li
{
  list-style-type: none;
  padding: 2px;
  text-align: center;
}

.sidepanel,.sidebox
{
  border: 1px solid #45686B;
  margin: 0 0 10px 0;
}

.sidebox
{
}

.sidepanel li
{
  border-top: 1px solid #45686B;
}

.sidebox p
{
  background: #25313B;
  margin: 0;
  padding: 5px;
}

#pagetrail {
  clear: right;
  display: inline;
  margin: 5px 12px;
  padding: 0;
  font-size: 0.88em;
}

#pagetrail ul
{
  padding: 0;
  margin: 0;
}

#pagetrail li
{
  list-style-type: none;
  padding: 2px;
  border-top: 1px solid #45686B;
  text-align: center;
}

#editor-comment {width: 70%;}
#editor-textarea {width: 100%;}

.diff
{
  width: 99%;
}

.diff-title
{
  background-color: #15282B;
}

.diff-title a
{
}

.diff-added
{
  background-color: #608060;
  vertical-align: sub;
}

.diff-removed
{
  background-color: #806060;
  vertical-align: sub;
}

.diff-added span
{
  background-color: #008000;
  color: black;
}

.diff-removed span
{
  background-color: #803030;
  color: black;
}

#preview
{
  border: 1px solid #45686B;
  margin-top: 10px;
  padding: 5px;
}

div#message
{
  background: #25313B;
  color: #A0A0A0;
  border: 1px solid #45686B;
  padding: 5px;
  margin: 0;
}

div#message p
{
  padding: 0;
  margin: 0;
}

div#content
{
  border: 1px solid #45686B;
  padding: 5px;
}

/* User Preferences */

.userpref table, .userpref td
{
  border: none;
}

table.RandomQuote
{
  padding: 0;
  margin: 0;
  margin-bottom: 2em;
  background-color: #25313B;
  color: #A0A0A0;
  border: 1px solid #45686B;
}

table.RandomQuote td
{
  padding: 0;
  margin: 0;
  margin-bottom: 5px
}

#RandomQuote_FortuneCookies p
{
  padding: 5px;
}