body
{
  font-family: verdana,georgia,arial,sans-serif;
  background: #05111B;
  color: #A0A0A0;
}

img
{
  border-width: 0;
}

pre {
  border: 1pt solid #45686B;
  background-color: #25313B;
  padding: 5pt;
  font-family: courier, monospace;
  font-weight: bold;
  white-space: pre;
  /* begin css 3 or browser specific rules - do not remove!
     see: http://forums.techguy.org/archive/index.php/t-249849.html */
  white-space: pre-wrap;
  word-wrap: break-word;
  white-space: -moz-pre-wrap;
  white-space: -pre-wrap;
  white-space: -o-pre-wrap;
  /* end css 3 or browser specific rules */
}

/* CSS for new code_area markup used by Colorizer and ParserBase */

div.codearea { /* the div makes the border */
	margin: 0.5em 0;
	padding: 0;
	border: 1pt solid #45686B;
	background-color: #25313B;
	color: black;
}

div.codearea pre { /* the pre has no border and is inside the div */
	margin: 0;
	padding: 10pt;
	border: none;
	font-weight: bold;
}

a.codenumbers { /* format of the line numbering link */
	margin: 0 10pt;
	font-size: 0.85em;
	color: gray;
	font-weight: bold;
}

/* format of certain syntax spans */
div.codearea pre span.LineNumber {color: #A0A0A0;}
div.codearea pre span.ID         {color: #A0A0A0;}
div.codearea pre span.Operator   {color: #0080C0;}
div.codearea pre span.Char       {color: #004080;}
div.codearea pre span.Comment    {color: #008000;}
div.codearea pre span.Number     {color: #0080C0;}
div.codearea pre span.String     {color: #A0A080;}
div.codearea pre span.SPChar     {color: #60A0A0;}
div.codearea pre span.ResWord    {color: #0080C0;}
div.codearea pre span.ConsWord   {color: #008080; font-weight: bold;}
div.codearea pre span.Error      {color: #FF8080; border: solid 1.5pt #FF0000;}
div.codearea pre span.ResWord2   {color: #0080ff; font-weight: bold;}
div.codearea pre span.Special    {color: #0000ff;}
div.codearea pre span.Preprc     {color: #803999;}

table
{
/*   margin: 0.5em 0 0 0.5em; */
  border-collapse: collapse;
  border: 1pt solid #45686B;
}

td
{
  padding: 0.25em 0.5em 0.25em 0.5em;
  border: 1pt solid #45686B;
}

td p
{
  margin: 0;
  padding: 0;
}
